import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Modal } from 'antd'
import { SettingOutlined } from '@ant-design/icons'

import SettingForm from './settingform'
import MKEmitter from '@/utils/events.js'

import './index.scss'

class TreeSettingComponent extends Component {
  static propTpyes = {
    MenuID: PropTypes.string,        // 菜单ID
    config: PropTypes.object,        // 菜单配置信息
    updatesetting: PropTypes.func
  }

  state = {
    menu: null,          // 菜单信息
    visible: false,      // 模态框控制
    loading: false       // 设置信息验证保存中
  }

  /**
   * @description 全局设置触发
   */
  changeSetting = () => {
    const { MenuID, config } = this.props
    let menu = {MenuID: MenuID, MenuName: config.MenuName, MenuNo: config.MenuNo}

    this.setState({
      visible: true,
      menu: menu
    })
    MKEmitter.emit('modalStatus', '数据源')
  }

  /**
   * @description 保存页面配置信息
   */
  settingSave = () => {
    const { config } = this.props

    this.setState({
      loading: true
    })
    this.settingRef.handleConfirm().then(res => {
      if (window.GLOB.funcs && window.GLOB.funcs.length > 0) {
        window.GLOB.funcs.forEach(m => {
          let reg = new RegExp('\\$ex@' + m.func_code + '@ex\\$', 'ig')
          res.scripts.forEach(item => {
            item.sql = item.sql.replace(reg, `/*$ex@${m.func_code}-begin*/\n${m.key_sql}\n/*@ex$-end*/`)
          })
          if (res.dataresource) {
            res.dataresource = res.dataresource.replace(reg, `/*$ex@${m.func_code}-begin*/\n${m.key_sql}\n/*@ex$-end*/`)
          }
        })
      }
      this.setState({
        visible: false,
        loading: false
      })

      res.show = config.setting.show || 'true'
      res.advanceType = config.setting.advanceType || 'modal'
      res.advanceWidth = config.setting.advanceWidth || 1000
      res.drawerPlacement = config.setting.drawerPlacement || 'right'
      res.searchRatio = config.setting.searchRatio || 6
      res.searchLwidth = config.setting.searchLwidth !== undefined ? config.setting.searchLwidth : 33.3

      this.props.updatesetting({...config, setting: res})

      MKEmitter.emit('modalStatus', false)
    }, () => {
      this.setState({
        loading: false
      })
    })
  }

  /**
   * @description 组件销毁，清除state更新
   */
  componentWillUnmount () {
    this.setState = () => {
      return
    }
  }

  render() {
    const { config } = this.props
    const { visible, loading } = this.state

    return (
      <div className="model-tree-menu-setting">
        <SettingOutlined onClick={this.changeSetting} />
        {/* 设置全局配置及列表数据源 */}
        <Modal
          wrapClassName="mk-pop-modal"
          visible={visible}
          width={'75vw'}
          maskClosable={false}
          onCancel={() => { MKEmitter.emit('modalStatus', false); this.setState({ visible: false })}}
          confirmLoading={loading}
          onOk={this.settingSave}
          destroyOnClose
        >
          <SettingForm
            config={config}
            menu={this.state.menu}
            inputSubmit={this.settingSave}
            wrappedComponentRef={(inst) => this.settingRef = inst}
          />
        </Modal>
      </div>
    )
  }
}

export default TreeSettingComponent